@@ -4,6 +4,7 @@
 #' Arguments to the function should be based on \url{www.waterqualitydata.us/webservices_documentation.jsp}
 #'
 #' @param \dots see \url{www.waterqualitydata.us/webservices_documentation.jsp} for a complete list of options
+#' @param zip logical to request data via downloading zip file. Default set to FALSE.
 #' @keywords data import WQP web service
 #' @return A data frame with at least the following columns:
 #' \tabular{lll}{ 
@@ -55,8 +56,9 @@
 #' 
 #' type <- "Stream"
 #' sites <- whatWQPsites(countycode="US:55:025",siteType=type)
+#' lakeSites <- whatWQPsites(siteType = "Lake, Reservoir, Impoundment", statecode = "US:55")
 #' }
-whatWQPsites <- function(...){
+whatWQPsites <- function(...,zip=FALSE){
 
   matchReturn <- list(...)
   
@@ -80,58 +82,32 @@ whatWQPsites <- function(...){
     }
     names(values)[names(values) == "stateCd"] <- "statecode"
   }
-
-  values <- gsub("%20","+",values)
   
   if("bBox" %in% names(values)){
     values['bBox'] <- gsub(pattern = ";", replacement = ",", x = values['bBox'])
   }
   
   values <- checkWQPdates(values)
+  
+  values <- sapply(values, function(x) URLencode(x, reserved = TRUE))
     
   urlCall <- paste(paste(names(values),values,sep="="),collapse="&")
   
   
   baseURL <- "http://www.waterqualitydata.us/Station/search?"
-  urlCall <- paste(baseURL,
+  urlCall <- paste0(baseURL,
                urlCall,
-               "&mimeType=tsv&sorted=no",sep = "")
-  
-  doc <- getWebServiceData(urlCall)
-  headerInfo <- attr(doc, "headerInfo")
-    
-  numToBeReturned <- as.numeric(headerInfo["Total-Site-Count"])
-  
-  if (!is.na(numToBeReturned) & numToBeReturned != 0){
- 
-    retval <- read.delim(textConnection(doc), header = TRUE,  
-                         dec=".", sep='\t', quote="",
-                         colClasses=c('character'), 
-                         fill = TRUE)    
-    actualNumReturned <- nrow(retval)
-    
-    if(actualNumReturned != numToBeReturned) warning(numToBeReturned, " sites were expected, ", actualNumReturned, " were returned")
-    
-    if("LatitudeMeasure" %in% names(retval)){
-      retval$LatitudeMeasure <- as.numeric(retval$LatitudeMeasure)
-    }
-    
-    if("LongitudeMeasure" %in% names(retval)){
-      retval$LongitudeMeasure <- as.numeric(retval$LongitudeMeasure)
-    }
-    
-    retval$queryTime <- Sys.time()
-    
-    return(retval)
-    
-  } else {
-    if(headerInfo['Total-Site-Count'] == "0"){
-      warning("No data returned")
-    }
-    
-    for(i in grep("Warning",names(headerInfo))){
-      warning(headerInfo[i])
-    }
+               "&mimeType=tsv&sorted=no")
+  if(zip){
+    urlCall <- paste0(urlCall,"&zip=yes")
   }
+  
+  retval <- importWQP(urlCall, zip=zip)
+  
+  attr(retval, "queryTime") <- Sys.time()
+  attr(retval, "url") <- urlCall
+  
+  return(retval)
+  
 
 }
